@@ -76,6 +76,9 @@ class ReadAllRequest:
     warehouse: str
     columns: typing.List[str]
 
+    partition_column_name: str = 'knowledge_hash'
+    partition_num: int = None
+
 
 @dataclass
 class ReadRequestBuildingBlocks:
@@ -110,11 +113,7 @@ class DataStoreHelper(ABC):
         pass
 
     @abstractmethod
-    def get_or_create_series_temporary_table(self, frequency: typing.Tuple[datetime.datetime, datetime.datetime, str]) -> Table:
-        pass
-
-    @abstractmethod
-    def initialize_series(self):
+    def get_series_table(self, frequency: typing.Tuple[datetime.datetime, datetime.datetime, str]) -> Table:
         pass
 
 
@@ -154,6 +153,9 @@ class ReadRequest:
 
     modifiers: typing.List[Modifier] = None
 
+    partition_column_name: str = 'knowledge_hash'
+    partition_num: int = None
+
     def get_derived_effective_start_dt(self) -> datetime.datetime:
         if self.effective_dating is not None:
             return self.get_min_effective_dt()
